'use strict'
{
    C3.Plugins.InstantGamesBridge.Acts = {
        // action parameters
        AddActionParameter(key, value) {
            this.setObjectValue(key, value, this.actionParametersContainer, true)
        },
        AddBoolActionParameter(key, value) {
            this.setObjectValue(key, value, this.actionParametersContainer, true)
        },

        // common
        Initialize() {
            if (this.isInitialized) {
                return Promise.resolve()
            }

            return new Promise(resolve => {
                window.bridge.initialize()
                    .then(() => {
                        window.bridge.advertisement.on('banner_state_changed', state => {
                            this.Trigger(this.conditions.OnBannerStateChanged)

                            switch (state) {
                                case window.bridge.BANNER_STATE.LOADING:
                                    this.Trigger(this.conditions.OnBannerLoading)
                                    break
                                case window.bridge.BANNER_STATE.SHOWN:
                                    this.Trigger(this.conditions.OnBannerShown)
                                    break
                                case window.bridge.BANNER_STATE.HIDDEN:
                                    this.Trigger(this.conditions.OnBannerHidden)
                                    break
                                case window.bridge.BANNER_STATE.FAILED:
                                    this.Trigger(this.conditions.OnBannerFailed)
                                    break
                            }
                        })

                        window.bridge.advertisement.on('interstitial_state_changed', state => {
                            this.Trigger(this.conditions.OnInterstitialStateChanged)

                            switch (state) {
                                case window.bridge.INTERSTITIAL_STATE.LOADING:
                                    this.Trigger(this.conditions.OnInterstitialLoading)
                                    break
                                case window.bridge.INTERSTITIAL_STATE.OPENED:
                                    this.Trigger(this.conditions.OnInterstitialOpened)
                                    break
                                case window.bridge.INTERSTITIAL_STATE.CLOSED:
                                    this.Trigger(this.conditions.OnInterstitialClosed)
                                    break
                                case window.bridge.INTERSTITIAL_STATE.FAILED:
                                    this.Trigger(this.conditions.OnInterstitialFailed)
                                    break
                            }
                        })

                        window.bridge.advertisement.on('rewarded_state_changed', state => {
                            this.Trigger(this.conditions.OnRewardedStateChanged)

                            switch (state) {
                                case window.bridge.REWARDED_STATE.LOADING:
                                    this.Trigger(this.conditions.OnRewardedLoading)
                                    break
                                case window.bridge.REWARDED_STATE.OPENED:
                                    this.Trigger(this.conditions.OnRewardedOpened)
                                    break
                                case window.bridge.REWARDED_STATE.REWARDED:
                                    this.Trigger(this.conditions.OnRewardedRewarded)
                                    break
                                case window.bridge.REWARDED_STATE.CLOSED:
                                    this.Trigger(this.conditions.OnRewardedClosed)
                                    break
                                case window.bridge.REWARDED_STATE.FAILED:
                                    this.Trigger(this.conditions.OnRewardedFailed)
                                    break
                            }
                        })

                        window.bridge.game.on('visibility_state_changed', state => {
                            this.Trigger(this.conditions.OnVisibilityStateChanged)
                        })
                    })
                    .finally(() => {
                        this.Trigger(this.conditions.OnInitializationCompleted)
                        resolve()

                        if (this.showInterstitialOnInit) {
                            if (window.bridge.platform.id === window.bridge.PLATFORM_ID.YANDEX || window.bridge.platform.id === window.bridge.PLATFORM_ID.GAME_DISTRIBUTION) {
                                window.bridge.advertisement.showInterstitial()
                            }
                        }
                    })
            })
        },


        // platfrom
        SendMessage(message) {
            switch (message) {
                case 0:
                    message = window.bridge.PLATFORM_MESSAGE.GAME_READY
                    break
                case 1:
                    message = window.bridge.PLATFORM_MESSAGE.IN_GAME_LOADING_STARTED
                    break
                case 2:
                    message = window.bridge.PLATFORM_MESSAGE.IN_GAME_LOADING_STOPPED
                    break
                case 3:
                    message = window.bridge.PLATFORM_MESSAGE.GAMEPLAY_STARTED
                    break
                case 4:
                    message = window.bridge.PLATFORM_MESSAGE.GAMEPLAY_STOPPED
                    break
                case 5:
                    message = window.bridge.PLATFORM_MESSAGE.PLAYER_GOT_ACHIEVEMENT
                    break
            }

            window.bridge.platform.sendMessage(message)
        },
        GetServerTime() {
            this.isLastActionCompletedSuccessfully = false

            return new Promise(resolve => {
                window.bridge.platform.getServerTime()
                    .then(result => {
                        this.isLastActionCompletedSuccessfully = true
                        this.serverTime = result
                    })
                    .catch(error => console.log(error))
                    .finally(() => {
                        this.Trigger(this.conditions.OnGetServerTimeCompleted)
                        resolve()
                    })
            })
        },


        // player
        AuthorizePlayer() {
            this.isLastActionCompletedSuccessfully = false
            this.isLastAuthorizePlayerAuthorizedSuccessfully = false
            return new Promise(resolve => {
                window.bridge.player.authorize(this.actionParametersContainer)
                    .then(() => {
                        this.isLastActionCompletedSuccessfully = true
                        this.isLastAuthorizePlayerAuthorizedSuccessfully = true
                    })
                    .catch(error => console.log(error))
                    .finally(() => {
                        this.actionParametersContainer = {}
                        this.Trigger(this.conditions.OnAuthorizePlayerCompleted)
                        resolve()
                    })
            })
        },


        // storage
        AppendStorageDataGetRequest(key) {
            this.storageDataGetRequestKeys.push(key)
        },
        SendStorageDataGetRequest(storageType) {
            this.isLastActionCompletedSuccessfully = false
            this.isStorageDataGetRequestSuccess = false

            switch (storageType) {
                case 0:
                    storageType = null
                    break
                case 1:
                    storageType = "local_storage"
                    break
                case 2:
                    storageType = "platform_internal"
                    break
            }

            return new Promise(resolve => {
                window.bridge.storage.get(this.storageDataGetRequestKeys, storageType)
                    .then(data => {
                        if (!this.storageData) {
                            this.storageData = {}
                        }

                        for (let i = 0; i < data.length; i++) {
                            let key = this.storageDataGetRequestKeys[i]
                            let value = data[i]
                            this.storageData[key] = value
                        }

                        this.isLastActionCompletedSuccessfully = true
                        this.isStorageDataGetRequestSuccess = true
                    })
                    .catch(error => console.log(error))
                    .finally(() => {
                        this.storageDataGetRequestKeys = []
                        this.Trigger(this.conditions.OnStorageDataGetRequestCompleted)
                        resolve()
                    })
            })
        },
        AppendStorageDataSetRequest(key, value) {
            this.storageDataSetRequestKeys.push(key)
            this.storageDataSetRequestValues.push(value)
        },
        SendStorageDataSetRequest(storageType) {
            this.isLastActionCompletedSuccessfully = false
            this.isStorageDataSetRequestSuccess = false

            switch (storageType) {
                case 0:
                    storageType = null
                    break
                case 1:
                    storageType = "local_storage"
                    break
                case 2:
                    storageType = "platform_internal"
                    break
            }

            return new Promise(resolve => {
                window.bridge.storage.set(this.storageDataSetRequestKeys, this.storageDataSetRequestValues, storageType)
                    .then(() => {
                        for (let i = 0; i < this.storageDataSetRequestKeys.length; i++) {
                            let key = this.storageDataSetRequestKeys[i]
                            this.storageData[key] = this.storageDataSetRequestValues[i]
                        }

                        this.isLastActionCompletedSuccessfully = true
                        this.isStorageDataSetRequestSuccess = true
                    })
                    .catch(error => console.log(error))
                    .finally(() => {
                        this.storageDataSetRequestKeys = []
                        this.storageDataSetRequestValues = []
                        this.Trigger(this.conditions.OnStorageDataSetRequestCompleted)
                        resolve()
                    })
            })
        },
        AppendStorageDataDeleteRequest(key) {
            this.storageDataDeleteRequestKeys.push(key)
        },
        SendStorageDataDeleteRequest(storageType) {
            this.isLastActionCompletedSuccessfully = false
            this.isStorageDataDeleteRequestSuccess = false

            switch (storageType) {
                case 0:
                    storageType = null
                    break
                case 1:
                    storageType = "local_storage"
                    break
                case 2:
                    storageType = "platform_internal"
                    break
            }

            return new Promise(resolve => {
                window.bridge.storage.delete(this.storageDataDeleteRequestKeys, storageType)
                    .then(() => {
                        if (this.storageData) {
                            for (let i = 0; i < this.storageDataDeleteRequestKeys.length; i++) {
                                let key = this.storageDataDeleteRequestKeys[i]
                                delete this.storageData[key]
                            }
                        }

                        this.isLastActionCompletedSuccessfully = true
                        this.isStorageDataDeleteRequestSuccess = true
                    })
                    .catch(error => console.log(error))
                    .finally(() => {
                        this.storageDataDeleteRequestKeys = []
                        this.Trigger(this.conditions.OnStorageDataDeleteRequestCompleted)
                        resolve()
                    })
            })
        },


        // advertisement
        SetMinimumDelayBetweenInterstitial(seconds) {
            window.bridge.advertisement.setMinimumDelayBetweenInterstitial(seconds)
        },
        ShowBanner() {
            window.bridge.advertisement.showBanner(this.actionParametersContainer)
            this.actionParametersContainer = {}
        },
        HideBanner() {
            window.bridge.advertisement.hideBanner()
        },
        ShowInterstitial(ignoreDelay) {
            window.bridge.advertisement.showInterstitial(ignoreDelay)
        },
        ShowRewarded() {
            window.bridge.advertisement.showRewarded()
        },
        CheckAdBlock() {
            this.isLastActionCompletedSuccessfully = false

            return new Promise(resolve => {
                window.bridge.advertisement.checkAdBlock()
                    .then(result => {
                        this.isLastActionCompletedSuccessfully = true
                        this.isAdBlockDetected = result
                    })
                    .catch(error => console.log(error))
                    .finally(() => {
                        this.Trigger(this.conditions.OnCheckAdBlockCompleted)
                        resolve()
                    })
            })
        },


        // social
        Share() {
            this.isLastActionCompletedSuccessfully = false
            this.isLastShareSharedSuccessfully = false

            return new Promise(resolve => {
                window.bridge.social.share(this.actionParametersContainer)
                    .then(() => {
                        this.isLastActionCompletedSuccessfully = true
                        this.isLastShareSharedSuccessfully = true
                    })
                    .catch(error => console.log(error))
                    .finally(() => {
                        this.actionParametersContainer = {}
                        this.Trigger(this.conditions.OnShareCompleted)
                        resolve()
                    })
            })
        },
        InviteFriends() {
            this.isLastActionCompletedSuccessfully = false
            this.isLastInviteFriendsInvitedSuccessfully = false

            return new Promise(resolve => {
                window.bridge.social.inviteFriends(this.actionParametersContainer)
                    .then(() => {
                        this.isLastActionCompletedSuccessfully = true
                        this.isLastInviteFriendsInvitedSuccessfully = true
                    })
                    .catch(error => console.log(error))
                    .finally(() => {
                        this.actionParametersContainer = {}
                        this.Trigger(this.conditions.OnInviteFriendsCompleted)
                        resolve()
                    })
            })
        },
        JoinCommunity() {
            this.isLastActionCompletedSuccessfully = false
            this.isLastJoinCommunityJoinedSuccessfully = false

            return new Promise(resolve => {
                window.bridge.social.joinCommunity(this.actionParametersContainer)
                    .then(() => {
                        this.isLastActionCompletedSuccessfully = true
                        this.isLastJoinCommunityJoinedSuccessfully = true
                    })
                    .catch(error => console.log(error))
                    .finally(() => {
                        this.actionParametersContainer = {}
                        this.Trigger(this.conditions.OnJoinCommunityCompleted)
                        resolve()
                    })
            })
        },
        CreatePost() {
            this.isLastActionCompletedSuccessfully = false
            this.isLastCreatePostCreatedSuccessfully = false

            return new Promise(resolve => {
                window.bridge.social.createPost(this.actionParametersContainer)
                    .then(() => {
                        this.isLastActionCompletedSuccessfully = true
                        this.isLastCreatePostCreatedSuccessfully = true
                    })
                    .catch(error => console.log(error))
                    .finally(() => {
                        this.actionParametersContainer = {}
                        this.Trigger(this.conditions.OnCreatePostCompleted)
                        resolve()
                    })
            })
        },
        AddToHomeScreen() {
            this.isLastActionCompletedSuccessfully = false
            this.isLastAddToHomeScreenAddedSuccessfully = false

            return new Promise(resolve => {
                window.bridge.social.addToHomeScreen()
                    .then(() => {
                        this.isLastActionCompletedSuccessfully = true
                        this.isLastAddToHomeScreenAddedSuccessfully = true
                    })
                    .catch(error => console.log(error))
                    .finally(() => {
                        this.Trigger(this.conditions.OnAddToHomeScreenCompleted)
                        resolve()
                    })
            })
        },
        AddToFavorites() {
            this.isLastActionCompletedSuccessfully = false
            this.isLastAddToFavoritesAddedSuccessfully = false

            return new Promise(resolve => {
                window.bridge.social.addToFavorites()
                    .then(() => {
                        this.isLastActionCompletedSuccessfully = true
                        this.isLastAddToFavoritesAddedSuccessfully = true
                    })
                    .catch(error => console.log(error))
                    .finally(() => {
                        this.Trigger(this.conditions.OnAddToFavoritesCompleted)
                        resolve()
                    })
            })
        },
        Rate() {
            this.isLastActionCompletedSuccessfully = false
            this.isLastRateRatedSuccessfully = false

            return new Promise(resolve => {
                window.bridge.social.rate()
                    .then(() => {
                        this.isLastActionCompletedSuccessfully = true
                        this.isLastRateRatedSuccessfully = true
                    })
                    .catch(error => console.log(error))
                    .finally(() => {
                        this.Trigger(this.conditions.OnRateCompleted)
                        resolve()
                    })
            })
        },


        LeaderboardSetScore() {
            this.isLastActionCompletedSuccessfully = false
            this.isLastLeaderboardSetScoreSetSuccessfully = false

            return new Promise(resolve => {
                window.bridge.leaderboard.setScore(this.actionParametersContainer)
                    .then(() => {
                        this.isLastActionCompletedSuccessfully = true
                        this.isLastLeaderboardSetScoreSetSuccessfully = true
                    })
                    .catch(error => console.log(error))
                    .finally(() => {
                        this.actionParametersContainer = {}
                        this.Trigger(this.conditions.OnLeaderboardSetScoreCompleted)
                        resolve()
                    })
            })
        },
        LeaderboardGetScore() {
            this.leaderboardPlayerScore = null
            this.isLastActionCompletedSuccessfully = false
            this.isLastLeaderboardGetScoreGotSuccessfully = false

            return new Promise(resolve => {
                window.bridge.leaderboard.getScore(this.actionParametersContainer)
                    .then(score => {
                        this.leaderboardPlayerScore = score
                        this.isLastActionCompletedSuccessfully = true
                        this.isLastLeaderboardGetScoreGotSuccessfully = true
                    })
                    .catch(error => console.log(error))
                    .finally(() => {
                        this.actionParametersContainer = {}
                        this.Trigger(this.conditions.OnLeaderboardGetScoreCompleted)
                        resolve()
                    })
            })
        },
        LeaderboardGetEntries() {
            this.leaderboardEntries = null
            this.isLastActionCompletedSuccessfully = false
            this.isLastLeaderboardGetEntriesGotSuccessfully = false

            return new Promise(resolve => {
                window.bridge.leaderboard.getEntries(this.actionParametersContainer)
                    .then(entries => {
                        this.leaderboardEntries = entries
                        this.isLastActionCompletedSuccessfully = true
                        this.isLastLeaderboardGetEntriesGotSuccessfully = true
                    })
                    .catch(error => console.log(error))
                    .finally(() => {
                        this.actionParametersContainer = {}
                        this.Trigger(this.conditions.OnLeaderboardGetEntriesCompleted)
                        resolve()
                    })
            })
        },
        LeaderboardShowNativePopup() {
            this.isLastActionCompletedSuccessfully = false
            this.isLastLeaderboardShowNativePopupShownSuccessfully = false

            return new Promise(resolve => {
                window.bridge.leaderboard.showNativePopup(this.actionParametersContainer)
                    .then(() => {
                        this.isLastActionCompletedSuccessfully = true
                        this.isLastLeaderboardShowNativePopupShownSuccessfully = true
                    })
                    .catch(error => console.log(error))
                    .finally(() => {
                        this.actionParametersContainer = {}
                        this.Trigger(this.conditions.OnShowNativePopupCompleted)
                        resolve()
                    })
            })
        },


        // payments
        PaymentsPurchase() {
            this.isLastActionCompletedSuccessfully = false
            this.isLastPaymentsPurchasePurchasedSuccessfully = false

            return new Promise(resolve => {
                window.bridge.payments.purchase(this.actionParametersContainer)
                    .then(() => {
                        this.isLastActionCompletedSuccessfully = true
                        this.isLastPaymentsPurchasePurchasedSuccessfully = true
                    })
                    .catch(error => console.log(error))
                    .finally(() => {
                        this.actionParametersContainer = {}
                        this.Trigger(this.conditions.OnPaymentsPurchaseCompleted)
                        resolve()
                    })
            })
        },

        PaymentsGetPurchases() {
            this.isLastActionCompletedSuccessfully = false
            this.isLastPaymentsGetPurchasesGotSuccessfully = false

            return new Promise(resolve => {
                window.bridge.payments.getPurchases()
                    .then(data => {
                        this.isLastActionCompletedSuccessfully = true
                        this.isLastPaymentsGetPurchasesGotSuccessfully = true
                        this.paymentsPurchases = data
                    })
                    .catch(error => console.log(error))
                    .finally(() => {
                        this.Trigger(this.conditions.OnPaymentsGetPurchasesCompleted)
                        resolve()
                    })
            })
        },

        PaymentsGetCatalog() {
            this.isLastActionCompletedSuccessfully = false
            this.isLastPaymentsGetCatalogGotSuccessfully = false

            return new Promise(resolve => {
                window.bridge.payments.getCatalog()
                    .then(data => {
                        this.isLastActionCompletedSuccessfully = true
                        this.isLastPaymentsGetCatalogGotSuccessfully = true
                        this.paymentsCatalog = data
                    })
                    .catch(error => console.log(error))
                    .finally(() => {
                        this.Trigger(this.conditions.OnPaymentsGetCatalogCompleted)
                        resolve()
                    })
            })
        },

        PaymentsConsumePurchase() {
            this.isLastActionCompletedSuccessfully = false
            this.isLastPaymentsConsumePurchaseConsumedSuccessfully = false

            return new Promise(resolve => {
                window.bridge.payments.consumePurchase(this.actionParametersContainer)
                    .then(() => {
                        this.isLastActionCompletedSuccessfully = true
                        this.isLastPaymentsConsumePurchaseConsumedSuccessfully = true
                    })
                    .catch(error => console.log(error))
                    .finally(() => {
                        this.actionParametersContainer = {}
                        this.Trigger(this.conditions.OnPaymentsConsumePurchaseCompleted)
                        resolve()
                    })
            })
        },

        // remote-config
        SendRemoteConfigGetRequest() {
            this.isLastActionCompletedSuccessfully = false
            this.isRemoteConfigGotSuccessfully = false

            return new Promise(resolve => {
                window.bridge.remoteConfig.get(this.actionParametersContainer)
                    .then(data => {
                        this.isLastActionCompletedSuccessfully = true
                        this.isRemoteConfigGotSuccessfully = true
                        this.remoteConfig = data
                    })
                    .catch(error => console.log(error))
                    .finally(() => {
                        this.actionParametersContainer = {}
                        this.Trigger(this.conditions.OnRemoteConfigGotCompleted)
                        resolve()
                    })
            })
        },
    }
}
